==> sword-1.5.5.tar.gz: sword-1.5.5/apps/windoze/CBuilder5/BibleCS/optionfrm.h <==
//---------------------------------------------------------------------------
#ifndef optionfrmH
#define optionfrmH
//---------------------------------------------------------------------------
#include <vcl\Classes.hpp>
#include <vcl\Controls.hpp>
#include <vcl\StdCtrls.hpp>
#include <vcl\Forms.hpp>
#include <vcl\ExtCtrls.hpp>
#include <vcl\Dialogs.hpp>
#include <ComCtrls.hpp>

#include "FontSel.h"
#include <Buttons.hpp>
#include <Menus.hpp>

const AnsiString COLOR_DIR = "colors\\";
const AnsiString COLOR_EXT = ".sch";

//---------------------------------------------------------------------------
class TOptionsfrm : public TForm
{
__published:	// IDE-managed Components
	TColorDialog *ColorDialogVS;
	TPanel *Panel2;
	TPageControl *PageControl1;
	TTabSheet *TabSheet1;
	TTabSheet *TabSheet2;
	TPanel *Panel1;
	TGroupBox *gbPersonalize;
	TCheckBox *AutoBMPersonal;
	TCheckBox *AutoBMOther;
	TGroupBox *gbDefModules;
	TComboBox *hebrewDefCB;
	TComboBox *greekDefCB;
	TComboBox *greekParseCB;
	TComboBox *hebrewParseCB;
	TLabel *Label5;
	TLabel *Label6;
	TLabel *Label7;
	TLabel *Label8;
	TGroupBox *gbDevos;
	TLabel *Label9;
	TComboBox *dailyDefaultCB;
	TCheckBox *devSplashCB;
	TCheckBox *devsAsDictsCB;
	TLabel *Label10;
	TComboBox *strongsNumsCB;
	TTabSheet *TabSheet3;
	TCheckBox *HintPopups;
	TLabel *Label4;
	TComboBox *localeCB;
	TPanel *Panel3;
	TGroupBox *gbColors;
	TLabel *Label2;
	TLabel *Label3;
	TRichEdit *RTFPreview;
	TComboBox *cmbTextSelect;
	TButton *btnFont;
	TCheckBox *AutoVSColor;
	TButton *btnCurrVerse;
	TButton *btnNumClr;
	TLabel *Label11;
	TLabel *Label13;
	TShape *shpCurrVSClr;
	TLabel *Label14;
	TComboBox *cmbSchemeSelect;
	TButton *btnFieldClr;
	TLabel *Label15;
	TColorDialog *ColorDialogField;
	TColorDialog *ColorDialogVerseNum;
	TPopupMenu *SavePopup;
	TMenuItem *SaveScheme;
	TMenuItem *Export;
	TMenuItem *Import;
	TSpeedButton *btnSave;
	TOpenDialog *OpenSchDlg;
	TSaveDialog *SaveSchDlg;
	TMenuItem *DeleteScheme1;
	TCheckBox *AutoLayout;
	TGroupBox *gbGloss;
		TCheckBox *glosAsDictsCB;
	TButton *btnModFonts;
	TLabel *Label1;
	TBitBtn *OkBtn;
	TBitBtn *CancelBtn;
	TCheckBox *HintStrongs;
	TLabel *Label12;
	TLabel *Label16;
	TShape *shpStrongClr;
	TButton *btnStrongClr;
	TShape *shpMorphClr;
	TButton *btnMorphClr;
	TShape *shpFieldClr;
	TColorDialog *ColorDialogStrongs;
	TColorDialog *ColorDialogMorph;
	TShape *shpNumClr;
	TCheckBox *HintWords;
	TComboBox *genDictCB;
	TLabel *Label17;
	TCheckBox *HintVLists;
	void __fastcall btnCurrVerseClick(TObject *Sender);
	void __fastcall FormCreate(TObject *Sender);
	void __fastcall FormShow(TObject *Sender);
	void __fastcall btnFontClick(TObject *Sender);
	void __fastcall shpCurrVSClrMouseDown(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
	void __fastcall btnNumClrClick(TObject *Sender);
	void __fastcall btnFieldClrClick(TObject *Sender);
	void __fastcall cmbTextSelectChange(TObject *Sender);
	void __fastcall cmbSchemeSelectChange(TObject *Sender);
	void __fastcall btnSaveScheme(TObject *Sender);
	void __fastcall SaveSchemeClick(TObject *Sender);
	void __fastcall ExportClick(TObject *Sender);
	void __fastcall ImportClick(TObject *Sender);
	void __fastcall DeleteClick(TObject *Sender);
	void __fastcall btnModFontsClick(TObject *Sender);
	void __fastcall HintPopupsClick(TObject *Sender);
	void __fastcall btnStrongClrClick(TObject *Sender);
	void __fastcall btnMorphClrClick(TObject *Sender);
	void __fastcall shpFieldClrMouseDown(TObject *Sender, TMouseButton Button,
		  TShiftState Shift, int X, int Y);
	void __fastcall shpStrongClrMouseDown(TObject *Sender,
		  TMouseButton Button, TShiftState Shift, int X, int Y);
	void __fastcall shpMorphClrMouseDown(TObject *Sender, TMouseButton Button,
		  TShiftState Shift, int X, int Y);
	void __fastcall shpNumClrMouseDown(TObject *Sender, TMouseButton Button,
          TShiftState Shift, int X, int Y);

private:	// User declarations
	static const char *defaultLocaleName;
	static const char *defaultLocaleDescription;
	CopyFontDlg(TFontSelFrm* lhs, const TFontSelFrm* rhs);
	void FindSchemeNames();
	void GetCurrentScheme();
public:
	 TFontSelFrm* FontDialogText;
	 TFontSelFrm* FontDialogComment;
	 TFontSelFrm* FontDialogLD;
	 TFontSelFrm* FontDialogPopup;
	 TFontSelFrm* FontDialogSearch;
	void LoadDispSettings(SWConfig* config);
	void LoadMiscSettings(SWConfig* config);
	void extractSettings(SWConfig* config);
	void UpdatePreview();
public:		// User declarations
	__fastcall TOptionsfrm(TComponent* Owner);
};
//---------------------------------------------------------------------------
extern TOptionsfrm *Optionsfrm;
//---------------------------------------------------------------------------
#endif

==> sword-1.5.6.tar.gz: sword-1.5.6/apps/windoze/CBuilder5/BibleCS/optionfrm.h <==
//---------------------------------------------------------------------------
#ifndef optionfrmH
#define optionfrmH
//---------------------------------------------------------------------------
#include <vcl\Classes.hpp>
#include <vcl\Controls.hpp>
#include <vcl\StdCtrls.hpp>
#include <vcl\Forms.hpp>
#include <vcl\ExtCtrls.hpp>
#include <vcl\Dialogs.hpp>
#include <ComCtrls.hpp>

#include "FontSel.h"
#include <Buttons.hpp>
#include <Menus.hpp>
#include "TntButtons.hpp"
#include "TntComCtrls.hpp"
#include "TntExtCtrls.hpp"
#include "TntMenus.hpp"
#include "TntStdCtrls.hpp"

const AnsiString COLOR_DIR = "colors\\";
const AnsiString COLOR_EXT = ".sch";

//---------------------------------------------------------------------------
class TOptionsfrm : public TForm
{
__published:	// IDE-managed Components
	TColorDialog *ColorDialogVS;
        TPanel *Panel2;
        TPageControl *PageControl1;
	TTabSheet *TabSheet1;
	TTabSheet *TabSheet2;
        TPanel *Panel1;
        TGroupBox *gbPersonalize;
        TCheckBox *AutoBMPersonal;
        TCheckBox *AutoBMOther;
        TGroupBox *gbDefModules;
        TComboBox *hebrewDefCB;
        TComboBox *greekDefCB;
        TComboBox *greekParseCB;
        TComboBox *hebrewParseCB;
        TLabel *Label5;
        TLabel *Label6;
        TLabel *Label7;
        TLabel *Label8;
        TGroupBox *gbDevos;
        TLabel *Label9;
        TComboBox *dailyDefaultCB;
        TCheckBox *devSplashCB;
        TCheckBox *devsAsDictsCB;
        TLabel *Label10;
        TComboBox *strongsNumsCB;
	TTabSheet *TabSheet3;
        TCheckBox *HintPopups;
        TLabel *Label4;
        TComboBox *localeCB;
        TPanel *Panel3;
        TGroupBox *gbColors;
        TLabel *Label2;
        TLabel *Label3;
        TRichEdit *RTFPreview;
        TComboBox *cmbTextSelect;
        TButton *btnFont;
        TCheckBox *AutoVSColor;
        TButton *btnCurrVerse;
        TButton *btnNumClr;
        TLabel *Label11;
        TLabel *Label13;
	TShape *shpCurrVSClr;
        TLabel *Label14;
        TComboBox *cmbSchemeSelect;
        TButton *btnFieldClr;
        TLabel *Label15;
	TColorDialog *ColorDialogField;
	TColorDialog *ColorDialogVerseNum;
        TPopupMenu *SavePopup;
        TMenuItem *SaveScheme;
        TMenuItem *Export;
        TMenuItem *Import;
        TSpeedButton *btnSave;
	TOpenDialog *OpenSchDlg;
	TSaveDialog *SaveSchDlg;
        TMenuItem *DeleteScheme1;
        TCheckBox *AutoLayout;
        TGroupBox *gbGloss;
        TCheckBox *glosAsDictsCB;
        TButton *btnModFonts;
        TLabel *Label1;
        TBitBtn *OkBtn;
        TBitBtn *CancelBtn;
        TCheckBox *HintStrongs;
        TLabel *Label12;
        TLabel *Label16;
	TShape *shpStrongClr;
        TButton *btnStrongClr;
	TShape *shpMorphClr;
        TButton *btnMorphClr;
	TShape *shpFieldClr;
	TColorDialog *ColorDialogStrongs;
	TColorDialog *ColorDialogMorph;
	TShape *shpNumClr;
        TCheckBox *HintWords;
        TComboBox *genDictCB;
        TLabel *Label17;
        TCheckBox *HintVLists;
	void __fastcall btnCurrVerseClick(TObject *Sender);
	void __fastcall FormCreate(TObject *Sender);
	void __fastcall FormShow(TObject *Sender);
	void __fastcall btnFontClick(TObject *Sender);
	void __fastcall shpCurrVSClrMouseDown(TObject *Sender, TMouseButton Button, TShiftState Shift, int X, int Y);
	void __fastcall btnNumClrClick(TObject *Sender);
	void __fastcall btnFieldClrClick(TObject *Sender);
	void __fastcall cmbTextSelectChange(TObject *Sender);
	void __fastcall cmbSchemeSelectChange(TObject *Sender);
	void __fastcall btnSaveScheme(TObject *Sender);
	void __fastcall SaveSchemeClick(TObject *Sender);
	void __fastcall ExportClick(TObject *Sender);
	void __fastcall ImportClick(TObject *Sender);
	void __fastcall DeleteClick(TObject *Sender);
	void __fastcall btnModFontsClick(TObject *Sender);
	void __fastcall HintPopupsClick(TObject *Sender);
	void __fastcall btnStrongClrClick(TObject *Sender);
	void __fastcall btnMorphClrClick(TObject *Sender);
	void __fastcall shpFieldClrMouseDown(TObject *Sender, TMouseButton Button,
		  TShiftState Shift, int X, int Y);
	void __fastcall shpStrongClrMouseDown(TObject *Sender,
		  TMouseButton Button, TShiftState Shift, int X, int Y);
	void __fastcall shpMorphClrMouseDown(TObject *Sender, TMouseButton Button,
		  TShiftState Shift, int X, int Y);
	void __fastcall shpNumClrMouseDown(TObject *Sender, TMouseButton Button,
          TShiftState Shift, int X, int Y);

private:	// User declarations
	static const char *defaultLocaleName;
	static const char *defaultLocaleDescription;
	CopyFontDlg(TFontSelFrm* lhs, const TFontSelFrm* rhs);
	void FindSchemeNames();
	void GetCurrentScheme();
public:
	 TFontSelFrm* FontDialogText;
	 TFontSelFrm* FontDialogComment;
	 TFontSelFrm* FontDialogLD;
	 TFontSelFrm* FontDialogPopup;
	 TFontSelFrm* FontDialogSearch;
         TFontSelFrm* FontDialogUI;
	void LoadDispSettings(SWConfig* config);
	void LoadMiscSettings(SWConfig* config);
	void extractSettings(SWConfig* config);
	void UpdatePreview();
public:		// User declarations
	__fastcall TOptionsfrm(TComponent* Owner);
};
//---------------------------------------------------------------------------
extern TOptionsfrm *Optionsfrm;
//---------------------------------------------------------------------------
#endif
